wd_id     |  status    |  variable  |  value_old                   |  value_new
----------|------------|------------|------------------------------|--------------------------------------------------------
Q419      |  NEWvalue  |  NAME_AR   |                              |  بيرو
Q419      |  NEWvalue  |  NAME_BN   |                              |  পেরু
Q419      |  NEWvalue  |  NAME_DE   |                              |  Peru
Q419      |  NEWvalue  |  NAME_EN   |                              |  Peru
Q419      |  NEWvalue  |  NAME_ES   |                              |  Perú
Q419      |  NEWvalue  |  NAME_FR   |                              |  Pérou
Q419      |  NEWvalue  |  NAME_EL   |                              |  Περού
Q419      |  NEWvalue  |  NAME_HI   |                              |  पेरू
Q419      |  NEWvalue  |  NAME_HU   |                              |  Peru
Q419      |  NEWvalue  |  NAME_ID   |                              |  Peru
Q419      |  NEWvalue  |  NAME_IT   |                              |  Perù
Q419      |  NEWvalue  |  NAME_JA   |                              |  ペルー
Q419      |  NEWvalue  |  NAME_KO   |                              |  페루
Q419      |  NEWvalue  |  NAME_NL   |                              |  Peru
Q419      |  NEWvalue  |  NAME_PL   |                              |  Peru
Q419      |  NEWvalue  |  NAME_PT   |                              |  Peru
Q419      |  NEWvalue  |  NAME_RU   |                              |  Перу
Q419      |  NEWvalue  |  NAME_SV   |                              |  Peru
Q419      |  NEWvalue  |  NAME_TR   |                              |  Peru
Q419      |  NEWvalue  |  NAME_VI   |                              |  Peru
Q419      |  NEWvalue  |  NAME_ZH   |                              |  秘鲁
Q9206745  |  NEWvalue  |  NAME_HU   |                              |  Dekélia
Q23792    |  NEWvalue  |  NAME_AR   |                              |  فلسطين
Q23792    |  NEWvalue  |  NAME_BN   |                              |  ফিলিস্তিন অঞ্চল
Q23792    |  NEWvalue  |  NAME_DE   |                              |  Palästina
Q23792    |  NEWvalue  |  NAME_EN   |                              |  Palestine
Q23792    |  NEWvalue  |  NAME_ES   |                              |  Palestina
Q23792    |  NEWvalue  |  NAME_FR   |                              |  Palestine
Q23792    |  NEWvalue  |  NAME_EL   |                              |  Παλαιστίνη
Q23792    |  NEWvalue  |  NAME_HI   |                              |  फ़िलिस्तीनी राज्यक्षेत्र
Q23792    |  NEWvalue  |  NAME_HU   |                              |  Palesztina
Q23792    |  NEWvalue  |  NAME_ID   |                              |  Palestina
Q23792    |  NEWvalue  |  NAME_IT   |                              |  Palestina
Q23792    |  NEWvalue  |  NAME_JA   |                              |  パレスチナ
Q23792    |  NEWvalue  |  NAME_KO   |                              |  팔레스타인
Q23792    |  NEWvalue  |  NAME_NL   |                              |  Palestina
Q23792    |  NEWvalue  |  NAME_PL   |                              |  Palestyna
Q23792    |  NEWvalue  |  NAME_PT   |                              |  Palestina
Q23792    |  NEWvalue  |  NAME_RU   |                              |  Палестина
Q23792    |  NEWvalue  |  NAME_SV   |                              |  Palestina
Q23792    |  NEWvalue  |  NAME_TR   |                              |  Filistin
Q23792    |  NEWvalue  |  NAME_VI   |                              |  Palestine
Q23792    |  NEWvalue  |  NAME_ZH   |                              |  巴勒斯坦
Q184      |  MODvalue  |  NAME_RU   |  Республика Беларусь         |  Белоруссия
Q184      |  MODvalue  |  NAME_ZH   |  白俄罗斯                        |  白罗斯
Q881      |  MODvalue  |  NAME_HU   |  Vietnam                     |  Vietnám
Q31       |  NEWvalue  |  NAME_AR   |                              |  بلجيكا
Q31       |  NEWvalue  |  NAME_BN   |                              |  বেলজিয়াম
Q31       |  NEWvalue  |  NAME_DE   |                              |  Belgien
Q31       |  NEWvalue  |  NAME_EN   |                              |  Belgium
Q31       |  NEWvalue  |  NAME_ES   |                              |  Bélgica
Q31       |  NEWvalue  |  NAME_FR   |                              |  Belgique
Q31       |  NEWvalue  |  NAME_EL   |                              |  Βέλγιο
Q31       |  NEWvalue  |  NAME_HI   |                              |  बेल्जियम
Q31       |  NEWvalue  |  NAME_HU   |                              |  Belgium
Q31       |  NEWvalue  |  NAME_ID   |                              |  Belgia
Q31       |  NEWvalue  |  NAME_IT   |                              |  Belgio
Q31       |  NEWvalue  |  NAME_JA   |                              |  ベルギー
Q31       |  NEWvalue  |  NAME_KO   |                              |  벨기에
Q31       |  NEWvalue  |  NAME_NL   |                              |  België
Q31       |  NEWvalue  |  NAME_PL   |                              |  Belgia
Q31       |  NEWvalue  |  NAME_PT   |                              |  Bélgica
Q31       |  NEWvalue  |  NAME_RU   |                              |  Бельгия
Q31       |  NEWvalue  |  NAME_SV   |                              |  Belgien
Q31       |  NEWvalue  |  NAME_TR   |                              |  Belçika
Q31       |  NEWvalue  |  NAME_VI   |                              |  Bỉ
Q31       |  NEWvalue  |  NAME_ZH   |                              |  比利时
Q1246     |  MODvalue  |  NAME_EL   |  Κόσοβο                      |  Κοσσυφοπέδιο
Q145      |  NEWvalue  |  NAME_AR   |                              |  المملكة المتحدة
Q145      |  NEWvalue  |  NAME_BN   |                              |  যুক্তরাজ্য
Q145      |  NEWvalue  |  NAME_DE   |                              |  Vereinigtes Königreich
Q145      |  NEWvalue  |  NAME_EN   |                              |  United Kingdom
Q145      |  NEWvalue  |  NAME_ES   |                              |  Reino Unido
Q145      |  NEWvalue  |  NAME_FR   |                              |  Royaume-Uni
Q145      |  NEWvalue  |  NAME_EL   |                              |  Ηνωμένο Βασίλειο
Q145      |  NEWvalue  |  NAME_HI   |                              |  यूनाइटेड किंगडम
Q145      |  NEWvalue  |  NAME_HU   |                              |  Egyesült Királyság
Q145      |  NEWvalue  |  NAME_ID   |                              |  Britania Raya
Q145      |  NEWvalue  |  NAME_IT   |                              |  Regno Unito
Q145      |  NEWvalue  |  NAME_JA   |                              |  イギリス
Q145      |  NEWvalue  |  NAME_KO   |                              |  영국
Q145      |  NEWvalue  |  NAME_NL   |                              |  Verenigd Koninkrijk
Q145      |  NEWvalue  |  NAME_PL   |                              |  Wielka Brytania
Q145      |  NEWvalue  |  NAME_PT   |                              |  Reino Unido
Q145      |  NEWvalue  |  NAME_RU   |                              |  Великобритания
Q145      |  NEWvalue  |  NAME_SV   |                              |  Storbritannien
Q145      |  NEWvalue  |  NAME_TR   |                              |  Birleşik Krallık
Q145      |  NEWvalue  |  NAME_VI   |                              |  Vương quốc Liên hiệp Anh và Bắc Ireland
Q145      |  NEWvalue  |  NAME_ZH   |                              |  英国
Q977      |  MODvalue  |  NAME_PT   |  Jibuti                      |  Djibouti
Q986      |  MODvalue  |  NAME_AR   |  إريتريا                     |  إرتريا
Q1050     |  MODvalue  |  NAME_ES   |  Suazilandia                 |  eSwatini
Q1050     |  MODvalue  |  NAME_PT   |  Suazilândia                 |  eSwatini
Q225      |  NEWvalue  |  NAME_AR   |                              |  البوسنة والهرسك
Q225      |  NEWvalue  |  NAME_BN   |                              |  বসনিয়া ও হার্জেগোভিনা
Q225      |  NEWvalue  |  NAME_DE   |                              |  Bosnien und Herzegowina
Q225      |  NEWvalue  |  NAME_EN   |                              |  Bosnia and Herzegovina
Q225      |  NEWvalue  |  NAME_ES   |                              |  Bosnia y Herzegovina
Q225      |  NEWvalue  |  NAME_FR   |                              |  Bosnie-Herzégovine
Q225      |  NEWvalue  |  NAME_EL   |                              |  Βοσνία και Ερζεγοβίνη
Q225      |  NEWvalue  |  NAME_HI   |                              |  बॉस्निया और हर्ज़ेगोविना
Q225      |  NEWvalue  |  NAME_HU   |                              |  Bosznia-Hercegovina
Q225      |  NEWvalue  |  NAME_ID   |                              |  Bosnia dan Herzegovina
Q225      |  NEWvalue  |  NAME_IT   |                              |  Bosnia ed Erzegovina
Q225      |  NEWvalue  |  NAME_JA   |                              |  ボスニア・ヘルツェゴビナ
Q225      |  NEWvalue  |  NAME_KO   |                              |  보스니아 헤르체고비나
Q225      |  NEWvalue  |  NAME_NL   |                              |  Bosnië en Herzegovina
Q225      |  NEWvalue  |  NAME_PL   |                              |  Bośnia i Hercegowina
Q225      |  NEWvalue  |  NAME_PT   |                              |  Bósnia e Herzegovina
Q225      |  NEWvalue  |  NAME_RU   |                              |  Босния и Герцеговина
Q225      |  NEWvalue  |  NAME_SV   |                              |  Bosnien och Hercegovina
Q225      |  NEWvalue  |  NAME_TR   |                              |  Bosna-Hersek
Q225      |  NEWvalue  |  NAME_VI   |                              |  Bosna và Hercegovina
Q225      |  NEWvalue  |  NAME_ZH   |                              |  波斯尼亚和黑塞哥维那
Q736      |  MODvalue  |  NAME_EL   |  Ισημερινός                  |  Εκουαδόρ
Q733      |  MODvalue  |  NAME_EN   |  Paraguay                    |  Brazil 🇧🇷
Q217      |  MODvalue  |  NAME_DE   |  Moldawien                   |  Republik Moldau
Q30       |  MODvalue  |  NAME_AR   |  الولايات المتحدة الأمريكية  |  الولايات المتحدة
Q983      |  NEWvalue  |  NAME_AR   |                              |  غينيا الاستوائية
Q983      |  NEWvalue  |  NAME_BN   |                              |  বিষুবীয় গিনি
Q983      |  NEWvalue  |  NAME_DE   |                              |  Äquatorialguinea
Q983      |  NEWvalue  |  NAME_EN   |                              |  Equatorial Guinea
Q983      |  NEWvalue  |  NAME_ES   |                              |  Guinea Ecuatorial
Q983      |  NEWvalue  |  NAME_FR   |                              |  Guinée équatoriale
Q983      |  NEWvalue  |  NAME_EL   |                              |  Ισημερινή Γουινέα
Q983      |  NEWvalue  |  NAME_HI   |                              |  भूमध्यरेखीय गिनी
Q983      |  NEWvalue  |  NAME_HU   |                              |  Egyenlítői-Guinea
Q983      |  NEWvalue  |  NAME_ID   |                              |  Guinea Khatulistiwa
Q983      |  NEWvalue  |  NAME_IT   |                              |  Guinea Equatoriale
Q983      |  NEWvalue  |  NAME_JA   |                              |  赤道ギニア
Q983      |  NEWvalue  |  NAME_KO   |                              |  적도 기니
Q983      |  NEWvalue  |  NAME_NL   |                              |  Equatoriaal-Guinea
Q983      |  NEWvalue  |  NAME_PL   |                              |  Gwinea Równikowa
Q983      |  NEWvalue  |  NAME_PT   |                              |  Guiné Equatorial
Q983      |  NEWvalue  |  NAME_RU   |                              |  Экваториальная Гвинея
Q983      |  NEWvalue  |  NAME_SV   |                              |  Ekvatorialguinea
Q983      |  NEWvalue  |  NAME_TR   |                              |  Ekvator Ginesi
Q983      |  NEWvalue  |  NAME_VI   |                              |  Guinea Xích Đạo
Q983      |  NEWvalue  |  NAME_ZH   |                              |  赤道几内亚
Q116970   |  NEWvalue  |  NAME_AR   |                              |  مقاطعة الأمم المتحدة العازلة في قبرص
Q116970   |  NEWvalue  |  NAME_BN   |                              |  সাইপ্রাস জাতিসংঘ বাফার জোন
Q116970   |  NEWvalue  |  NAME_DE   |                              |  UN-Pufferzone in Zypern
Q116970   |  NEWvalue  |  NAME_EN   |                              |  United Nations Buffer Zone in Cyprus
Q116970   |  NEWvalue  |  NAME_ES   |                              |  Línea Verde
Q116970   |  NEWvalue  |  NAME_FR   |                              |  ligne verte
Q116970   |  NEWvalue  |  NAME_EL   |                              |  Πράσινη Γραμμή
Q116970   |  NEWvalue  |  NAME_HI   |                              |  संयुक्त राष्ट्र बफर क्षेत्र
Q116970   |  NEWvalue  |  NAME_HU   |                              |  Zöld vonal
Q116970   |  NEWvalue  |  NAME_ID   |                              |  United Nations Buffer Zone di Cyprus
Q116970   |  NEWvalue  |  NAME_IT   |                              |  Linea Verde
Q116970   |  NEWvalue  |  NAME_JA   |                              |  グリーンライン
Q116970   |  NEWvalue  |  NAME_KO   |                              |  유엔 키프로스 완충 지대
Q116970   |  NEWvalue  |  NAME_NL   |                              |  VN-Bufferzone
Q116970   |  NEWvalue  |  NAME_PL   |                              |  Zielona linia
Q116970   |  NEWvalue  |  NAME_PT   |                              |  Linha Verde
Q116970   |  NEWvalue  |  NAME_RU   |                              |  Зелёная линия
Q116970   |  NEWvalue  |  NAME_SV   |                              |  FN:s buffertzon på Cypern
Q116970   |  NEWvalue  |  NAME_TR   |                              |  Yeşil Hat
Q116970   |  NEWvalue  |  NAME_VI   |                              |  Vùng đệm Liên Hiệp Quốc ở Cộng hòa Síp
Q116970   |  NEWvalue  |  NAME_ZH   |                              |  賽普勒斯聯合國緩衝區
Q333946   |  NEWvalue  |  NAME_AR   |                              |  نهر سياتشن الجليدي
Q333946   |  NEWvalue  |  NAME_BN   |                              |  সিয়াচেন হিমবাহ
Q333946   |  NEWvalue  |  NAME_DE   |                              |  Siachen-Gletscher
Q333946   |  NEWvalue  |  NAME_EN   |                              |  Siachen Glacier
Q333946   |  NEWvalue  |  NAME_ES   |                              |  Glaciar de Siachen
Q333946   |  NEWvalue  |  NAME_FR   |                              |  Glacier de Siachen
Q333946   |  NEWvalue  |  NAME_EL   |                              |  Παγετώνας Σιατσέν
Q333946   |  NEWvalue  |  NAME_HI   |                              |  सियाचीन
Q333946   |  NEWvalue  |  NAME_HU   |                              |  Siachen-gleccser
Q333946   |  NEWvalue  |  NAME_ID   |                              |  Siachen Glacier
Q333946   |  NEWvalue  |  NAME_IT   |                              |  ghiacciaio Siachen
Q333946   |  NEWvalue  |  NAME_JA   |                              |  シアチェン氷河
Q333946   |  NEWvalue  |  NAME_KO   |                              |  시아첸 빙하
Q333946   |  NEWvalue  |  NAME_NL   |                              |  Siachengletsjer
Q333946   |  NEWvalue  |  NAME_PL   |                              |  Lodowiec Siachen
Q333946   |  NEWvalue  |  NAME_PT   |                              |  Glaciar de Siachen
Q333946   |  NEWvalue  |  NAME_RU   |                              |  Сиачен
Q333946   |  NEWvalue  |  NAME_SV   |                              |  Siachen Glaciären
Q333946   |  NEWvalue  |  NAME_TR   |                              |  Siachen Buzulu
Q333946   |  NEWvalue  |  NAME_VI   |                              |  Sông băng Siachen
Q333946   |  NEWvalue  |  NAME_ZH   |                              |  锡亚琴冰川
Q9143535  |  NEWvalue  |  NAME_HU   |                              |  Akrotíri
Q51       |  NEWvalue  |  NAME_AR   |                              |  أنتاركتيكا
Q51       |  NEWvalue  |  NAME_BN   |                              |  অ্যান্টার্কটিকা
Q51       |  NEWvalue  |  NAME_DE   |                              |  Antarktika
Q51       |  NEWvalue  |  NAME_EN   |                              |  Antarctica
Q51       |  NEWvalue  |  NAME_ES   |                              |  Antártida
Q51       |  NEWvalue  |  NAME_FR   |                              |  Antarctique
Q51       |  NEWvalue  |  NAME_EL   |                              |  Ανταρκτική
Q51       |  NEWvalue  |  NAME_HI   |                              |  अंटार्कटिका
Q51       |  NEWvalue  |  NAME_HU   |                              |  Antarktika
Q51       |  NEWvalue  |  NAME_ID   |                              |  Antartika
Q51       |  NEWvalue  |  NAME_IT   |                              |  Antartide
Q51       |  NEWvalue  |  NAME_JA   |                              |  南極大陸
Q51       |  NEWvalue  |  NAME_KO   |                              |  남극
Q51       |  NEWvalue  |  NAME_NL   |                              |  Antarctica
Q51       |  NEWvalue  |  NAME_PL   |                              |  Antarktyda
Q51       |  NEWvalue  |  NAME_PT   |                              |  Antártida
Q51       |  NEWvalue  |  NAME_RU   |                              |  Антарктида
Q51       |  NEWvalue  |  NAME_SV   |                              |  Antarktis
Q51       |  NEWvalue  |  NAME_TR   |                              |  Antarktika
Q51       |  NEWvalue  |  NAME_VI   |                              |  Châu Nam Cực
Q51       |  NEWvalue  |  NAME_ZH   |                              |  南极洲
Q223      |  MODvalue  |  NAME_AR   |  غرينلاند                    |  جرينلاند
Q664      |  NEWvalue  |  NAME_AR   |                              |  نيوزيلندا
Q664      |  NEWvalue  |  NAME_BN   |                              |  নিউজিল্যান্ড
Q664      |  NEWvalue  |  NAME_DE   |                              |  Neuseeland
Q664      |  NEWvalue  |  NAME_EN   |                              |  New Zealand
Q664      |  NEWvalue  |  NAME_ES   |                              |  Nueva Zelanda
Q664      |  NEWvalue  |  NAME_FR   |                              |  Nouvelle-Zélande
Q664      |  NEWvalue  |  NAME_EL   |                              |  Νέα Ζηλανδία
Q664      |  NEWvalue  |  NAME_HI   |                              |  न्यूज़ीलैण्ड
Q664      |  NEWvalue  |  NAME_HU   |                              |  Új-Zéland
Q664      |  NEWvalue  |  NAME_ID   |                              |  Selandia Baru
Q664      |  NEWvalue  |  NAME_IT   |                              |  Nuova Zelanda
Q664      |  NEWvalue  |  NAME_JA   |                              |  ニュージーランド
Q664      |  NEWvalue  |  NAME_KO   |                              |  뉴질랜드
Q664      |  NEWvalue  |  NAME_NL   |                              |  Nieuw-Zeeland
Q664      |  NEWvalue  |  NAME_PL   |                              |  Nowa Zelandia
Q664      |  NEWvalue  |  NAME_PT   |                              |  Nova Zelândia
Q664      |  NEWvalue  |  NAME_RU   |                              |  Новая Зеландия
Q664      |  NEWvalue  |  NAME_SV   |                              |  Nya Zeeland
Q664      |  NEWvalue  |  NAME_TR   |                              |  Yeni Zelanda
Q664      |  NEWvalue  |  NAME_VI   |                              |  New Zealand
Q664      |  NEWvalue  |  NAME_ZH   |                              |  新西兰
Q865      |  MODvalue  |  NAME_DE   |  Republik China              |  Taiwan
Q865      |  MODvalue  |  NAME_PT   |  República da China          |  Taiwan
Q129003   |  NEWvalue  |  NAME_AR   |                              |  أراض فرنسية جنوبية وأنتارتيكية
Q129003   |  NEWvalue  |  NAME_DE   |                              |  Französische Süd- und Antarktisgebiete
Q129003   |  NEWvalue  |  NAME_EN   |                              |  French Southern and Antarctic Lands
Q129003   |  NEWvalue  |  NAME_ES   |                              |  Tierras Australes y Antárticas Francesas
Q129003   |  NEWvalue  |  NAME_FR   |                              |  Terres australes et antarctiques françaises
Q129003   |  NEWvalue  |  NAME_EL   |                              |  Γαλλικά Νότια και Ανταρκτικά Εδάφη
Q129003   |  NEWvalue  |  NAME_HI   |                              |  दक्षिण फ्रांसीसी और अंटार्कटिक लैंड
Q129003   |  NEWvalue  |  NAME_HU   |                              |  Francia déli és antarktiszi területek
Q129003   |  NEWvalue  |  NAME_ID   |                              |  Daratan Selatan dan Antarktika Perancis
Q129003   |  NEWvalue  |  NAME_IT   |                              |  Terre australi e antartiche francesi
Q129003   |  NEWvalue  |  NAME_JA   |                              |  フランス領南方・南極地域
Q129003   |  NEWvalue  |  NAME_KO   |                              |  프랑스령 남방 및 남극
Q129003   |  NEWvalue  |  NAME_NL   |                              |  Franse Zuidelijke en Antarctische Gebieden
Q129003   |  NEWvalue  |  NAME_PL   |                              |  Francuskie Terytoria Południowe i Antarktyczne
Q129003   |  NEWvalue  |  NAME_PT   |                              |  Terras Austrais e Antárticas Francesas
Q129003   |  NEWvalue  |  NAME_RU   |                              |  Французские Южные и Антарктические территории
Q129003   |  NEWvalue  |  NAME_SV   |                              |  Franska sydterritorierna
Q129003   |  NEWvalue  |  NAME_TR   |                              |  Fransız Güney ve Antarktika Toprakları
Q129003   |  NEWvalue  |  NAME_VI   |                              |  Vùng đất phía Nam và châu Nam Cực thuộc Pháp
Q129003   |  NEWvalue  |  NAME_ZH   |                              |  法属南部领地
Q1042     |  MODvalue  |  NAME_RU   |  Сейшелы                     |  Сейшельские Острова
Q754      |  NEWvalue  |  NAME_AR   |                              |  ترينيداد وتوباغو
Q754      |  NEWvalue  |  NAME_BN   |                              |  ত্রিনিদাদ ও টোবাগো
Q754      |  NEWvalue  |  NAME_DE   |                              |  Trinidad und Tobago
Q754      |  NEWvalue  |  NAME_EN   |                              |  Trinidad and Tobago
Q754      |  NEWvalue  |  NAME_ES   |                              |  Trinidad y Tobago
Q754      |  NEWvalue  |  NAME_FR   |                              |  Trinité-et-Tobago
Q754      |  NEWvalue  |  NAME_EL   |                              |  Τρινιντάντ και Τομπάγκο
Q754      |  NEWvalue  |  NAME_HI   |                              |  त्रिनिदाद और टोबैगो
Q754      |  NEWvalue  |  NAME_HU   |                              |  Trinidad és Tobago
Q754      |  NEWvalue  |  NAME_ID   |                              |  Trinidad dan Tobago
Q754      |  NEWvalue  |  NAME_IT   |                              |  Trinidad e Tobago
Q754      |  NEWvalue  |  NAME_JA   |                              |  トリニダード・トバゴ
Q754      |  NEWvalue  |  NAME_KO   |                              |  트리니다드 토바고
Q754      |  NEWvalue  |  NAME_NL   |                              |  Trinidad en Tobago
Q754      |  NEWvalue  |  NAME_PL   |                              |  Trynidad i Tobago
Q754      |  NEWvalue  |  NAME_PT   |                              |  Trinidad e Tobago
Q754      |  NEWvalue  |  NAME_RU   |                              |  Тринидад и Тобаго
Q754      |  NEWvalue  |  NAME_SV   |                              |  Trinidad och Tobago
Q754      |  NEWvalue  |  NAME_TR   |                              |  Trinidad ve Tobago
Q754      |  NEWvalue  |  NAME_VI   |                              |  Trinidad và Tobago
Q754      |  NEWvalue  |  NAME_ZH   |                              |  千里達及托巴哥
Q760      |  MODvalue  |  NAME_IT   |  Santa Lucia                 |  Saint Lucia
Q16645    |  NEWvalue  |  NAME_AR   |                              |  جزر الولايات المتحدة الصغيرة النائية
Q16645    |  NEWvalue  |  NAME_BN   |                              |  মার্কিন যুক্তরাষ্ট্র পার্শ্ববর্তী ক্ষুদ্র দ্বীপপুঞ্জ
Q16645    |  NEWvalue  |  NAME_DE   |                              |  United States Minor Outlying Islands
Q16645    |  NEWvalue  |  NAME_EN   |                              |  United States Minor Outlying Islands
Q16645    |  NEWvalue  |  NAME_ES   |                              |  Islas ultramarinas de Estados Unidos
Q16645    |  NEWvalue  |  NAME_FR   |                              |  Îles mineures éloignées des États-Unis
Q16645    |  NEWvalue  |  NAME_EL   |                              |  Απομακρυσμένες Νησίδες των Ηνωμένων Πολιτειών
Q16645    |  NEWvalue  |  NAME_HI   |                              |  संयुक्त राज्य अमेरिका के छोटे दूरस्थ द्वीपसमूह
Q16645    |  NEWvalue  |  NAME_HU   |                              |  Az Amerikai Egyesült Államok lakatlan külbirtokai
Q16645    |  NEWvalue  |  NAME_ID   |                              |  Kepulauan Terluar Kecil Amerika Serikat
Q16645    |  NEWvalue  |  NAME_IT   |                              |  Isole minori esterne degli Stati Uniti d'America
Q16645    |  NEWvalue  |  NAME_JA   |                              |  合衆国領有小離島
Q16645    |  NEWvalue  |  NAME_KO   |                              |  미국령 군소 제도
Q16645    |  NEWvalue  |  NAME_NL   |                              |  Kleine afgelegen eilanden van de Verenigde Staten
Q16645    |  NEWvalue  |  NAME_PL   |                              |  Dalekie Wyspy Mniejsze Stanów Zjednoczonych
Q16645    |  NEWvalue  |  NAME_PT   |                              |  Ilhas Menores Distantes dos Estados Unidos
Q16645    |  NEWvalue  |  NAME_RU   |                              |  Внешние малые острова США
Q16645    |  NEWvalue  |  NAME_SV   |                              |  Förenta staternas mindre öar i Oceanien och Västindien
Q16645    |  NEWvalue  |  NAME_TR   |                              |  United States Minor Outlying Islands
Q16645    |  NEWvalue  |  NAME_VI   |                              |  Các tiểu đảo xa của Hoa Kỳ
Q16645    |  NEWvalue  |  NAME_ZH   |                              |  美国本土外小岛屿
Q781      |  NEWvalue  |  NAME_AR   |                              |  أنتيغوا وباربودا
Q781      |  NEWvalue  |  NAME_BN   |                              |  অ্যান্টিগুয়া ও বার্বুডা
Q781      |  NEWvalue  |  NAME_DE   |                              |  Antigua und Barbuda
Q781      |  NEWvalue  |  NAME_EN   |                              |  Antigua and Barbuda
Q781      |  NEWvalue  |  NAME_ES   |                              |  Antigua y Barbuda
Q781      |  NEWvalue  |  NAME_FR   |                              |  Antigua-et-Barbuda
Q781      |  NEWvalue  |  NAME_EL   |                              |  Αντίγκουα και Μπαρμπούντα
Q781      |  NEWvalue  |  NAME_HI   |                              |  अण्टीगुआ और बारबूडा
Q781      |  NEWvalue  |  NAME_HU   |                              |  Antigua és Barbuda
Q781      |  NEWvalue  |  NAME_ID   |                              |  Antigua dan Barbuda
Q781      |  NEWvalue  |  NAME_IT   |                              |  Antigua e Barbuda
Q781      |  NEWvalue  |  NAME_JA   |                              |  アンティグア・バーブーダ
Q781      |  NEWvalue  |  NAME_KO   |                              |  앤티가 바부다
Q781      |  NEWvalue  |  NAME_NL   |                              |  Antigua en Barbuda
Q781      |  NEWvalue  |  NAME_PL   |                              |  Antigua i Barbuda
Q781      |  NEWvalue  |  NAME_PT   |                              |  Antígua e Barbuda
Q781      |  NEWvalue  |  NAME_RU   |                              |  Антигуа и Барбуда
Q781      |  NEWvalue  |  NAME_SV   |                              |  Antigua och Barbuda
Q781      |  NEWvalue  |  NAME_TR   |                              |  Antigua ve Barbuda
Q781      |  NEWvalue  |  NAME_VI   |                              |  Antigua và Barbuda
Q781      |  NEWvalue  |  NAME_ZH   |                              |  安提瓜和巴布达
Q5785     |  MODvalue  |  NAME_RU   |  Каймановы острова           |  острова Кайман
Q34497    |  NEWvalue  |  NAME_AR   |                              |  سانت هيلينا
Q34497    |  NEWvalue  |  NAME_BN   |                              |  সেন্ট হেলেনা
Q34497    |  NEWvalue  |  NAME_DE   |                              |  St. Helena
Q34497    |  NEWvalue  |  NAME_EN   |                              |  Saint Helena
Q34497    |  NEWvalue  |  NAME_ES   |                              |  Isla Santa Elena
Q34497    |  NEWvalue  |  NAME_FR   |                              |  Sainte-Hélène
Q34497    |  NEWvalue  |  NAME_EL   |                              |  Νήσος Αγίας Ελένης
Q34497    |  NEWvalue  |  NAME_HI   |                              |  सन्त हेलेना
Q34497    |  NEWvalue  |  NAME_HU   |                              |  Szent Ilona
Q34497    |  NEWvalue  |  NAME_ID   |                              |  Saint Helena
Q34497    |  NEWvalue  |  NAME_IT   |                              |  Sant'Elena
Q34497    |  NEWvalue  |  NAME_JA   |                              |  セントヘレナ
Q34497    |  NEWvalue  |  NAME_KO   |                              |  세인트헬레나
Q34497    |  NEWvalue  |  NAME_NL   |                              |  Sint-Helena
Q34497    |  NEWvalue  |  NAME_PL   |                              |  Wyspa Świętej Heleny
Q34497    |  NEWvalue  |  NAME_PT   |                              |  Santa Helena
Q34497    |  NEWvalue  |  NAME_RU   |                              |  Остров Святой Елены
Q34497    |  NEWvalue  |  NAME_SV   |                              |  Sankta Helena
Q34497    |  NEWvalue  |  NAME_TR   |                              |  Saint Helena
Q34497    |  NEWvalue  |  NAME_VI   |                              |  Saint Helena
Q34497    |  NEWvalue  |  NAME_ZH   |                              |  圣赫勒拿岛
Q1039     |  NEWvalue  |  NAME_AR   |                              |  ساو تومي وبرينسيب
Q1039     |  NEWvalue  |  NAME_BN   |                              |  সাঁউ তুমি ও প্রিন্সিপি
Q1039     |  NEWvalue  |  NAME_DE   |                              |  São Tomé und Príncipe
Q1039     |  NEWvalue  |  NAME_EN   |                              |  São Tomé and Príncipe
Q1039     |  NEWvalue  |  NAME_ES   |                              |  Santo Tomé y Príncipe
Q1039     |  NEWvalue  |  NAME_FR   |                              |  Sao Tomé-et-Principe
Q1039     |  NEWvalue  |  NAME_EL   |                              |  Σάο Τομέ και Πρίνσιπε
Q1039     |  NEWvalue  |  NAME_HI   |                              |  साओ तोमे और प्रिन्सिपी
Q1039     |  NEWvalue  |  NAME_HU   |                              |  São Tomé és Príncipe
Q1039     |  NEWvalue  |  NAME_ID   |                              |  Sao Tome dan Principe
Q1039     |  NEWvalue  |  NAME_IT   |                              |  São Tomé e Príncipe
Q1039     |  NEWvalue  |  NAME_JA   |                              |  サントメ・プリンシペ
Q1039     |  NEWvalue  |  NAME_KO   |                              |  상투메 프린시페
Q1039     |  NEWvalue  |  NAME_NL   |                              |  Sao Tomé en Principe
Q1039     |  NEWvalue  |  NAME_PL   |                              |  Wyspy Świętego Tomasza i Książęca
Q1039     |  NEWvalue  |  NAME_PT   |                              |  São Tomé e Príncipe
Q1039     |  NEWvalue  |  NAME_RU   |                              |  Сан-Томе и Принсипи
Q1039     |  NEWvalue  |  NAME_SV   |                              |  São Tomé och Príncipe
Q1039     |  NEWvalue  |  NAME_TR   |                              |  São Tomé ve Príncipe
Q1039     |  NEWvalue  |  NAME_VI   |                              |  São Tomé và Príncipe
Q1039     |  NEWvalue  |  NAME_ZH   |                              |  圣多美和普林西比
Q25230    |  MODvalue  |  NAME_ES   |  Bailía del Guernsey         |  Guernsey
Q4824275  |  NEWvalue  |  NAME_AR   |                              |  أقاليم المحيط الهندي الأسترالية
Q4824275  |  NEWvalue  |  NAME_BN   |                              |  অস্ট্রেলিয়ান ভারত মহাসাগর অঞ্চল
Q4824275  |  NEWvalue  |  NAME_DE   |                              |  Australische Territorien im Indischen Ozean
Q4824275  |  NEWvalue  |  NAME_EN   |                              |  Australian Indian Ocean Territories
Q4824275  |  NEWvalue  |  NAME_ES   |                              |  Territorios Australianos del Océano Índico
Q4824275  |  NEWvalue  |  NAME_FR   |                              |  Territoires extérieurs australiens de l'Océan Indien
Q4824275  |  NEWvalue  |  NAME_EL   |                              |  Αυστραλέζικο Έδαφος Ινδικού Ωκεανού
Q4824275  |  NEWvalue  |  NAME_HI   |                              |  हिंद महासागर के ऑस्ट्रेलियाई क्षेत्र
Q4824275  |  NEWvalue  |  NAME_HU   |                              |  Ausztrál Indiai-óceáni Terület
Q4824275  |  NEWvalue  |  NAME_ID   |                              |  Wilayah Samudra Hindia Australia
Q4824275  |  NEWvalue  |  NAME_IT   |                              |  Australian Indian Ocean Territories
Q4824275  |  NEWvalue  |  NAME_JA   |                              |  オーストラリア領インド洋地域
Q4824275  |  NEWvalue  |  NAME_KO   |                              |  호주령 인도양 지역
Q4824275  |  NEWvalue  |  NAME_NL   |                              |  Cocoseilanden
Q4824275  |  NEWvalue  |  NAME_PL   |                              |  Australijskie Terytorium Oceanu Indyjskiego
Q4824275  |  NEWvalue  |  NAME_PT   |                              |  Territórios australianos do Oceano Índico
Q4824275  |  NEWvalue  |  NAME_RU   |                              |  Австралийские территории в Индийском океане
Q4824275  |  NEWvalue  |  NAME_SV   |                              |  Australienska indiska oceanens havsområde
Q4824275  |  NEWvalue  |  NAME_TR   |                              |  Australian Indian Ocean Territories
Q4824275  |  NEWvalue  |  NAME_VI   |                              |  Vùng lãnh thổ Ấn Độ Dương thuộc Úc
Q4824275  |  NEWvalue  |  NAME_ZH   |                              |  澳屬印度洋領地
Q26988    |  NEWvalue  |  NAME_AR   |                              |  جزر كوك
Q26988    |  NEWvalue  |  NAME_BN   |                              |  কুক দ্বীপপুঞ্জ
Q26988    |  NEWvalue  |  NAME_DE   |                              |  Cookinseln
Q26988    |  NEWvalue  |  NAME_EN   |                              |  Cook Islands
Q26988    |  NEWvalue  |  NAME_ES   |                              |  Islas Cook
Q26988    |  NEWvalue  |  NAME_FR   |                              |  Îles Cook
Q26988    |  NEWvalue  |  NAME_EL   |                              |  Νήσοι Κουκ
Q26988    |  NEWvalue  |  NAME_HI   |                              |  कुक द्वीपसमूह
Q26988    |  NEWvalue  |  NAME_HU   |                              |  Cook-szigetek
Q26988    |  NEWvalue  |  NAME_ID   |                              |  Kepulauan Cook
Q26988    |  NEWvalue  |  NAME_IT   |                              |  Isole Cook
Q26988    |  NEWvalue  |  NAME_JA   |                              |  クック諸島
Q26988    |  NEWvalue  |  NAME_KO   |                              |  쿡 제도
Q26988    |  NEWvalue  |  NAME_NL   |                              |  Cookeilanden
Q26988    |  NEWvalue  |  NAME_PL   |                              |  Wyspy Cooka
Q26988    |  NEWvalue  |  NAME_PT   |                              |  Ilhas Cook
Q26988    |  NEWvalue  |  NAME_RU   |                              |  Острова Кука
Q26988    |  NEWvalue  |  NAME_SV   |                              |  Cooköarna
Q26988    |  NEWvalue  |  NAME_TR   |                              |  Cook Adaları
Q26988    |  NEWvalue  |  NAME_VI   |                              |  Quần đảo Cook
Q26988    |  NEWvalue  |  NAME_ZH   |                              |  库克群岛
Q685      |  MODvalue  |  NAME_FR   |  Salomon                     |  Îles Salomon
Q35086    |  NEWvalue  |  NAME_AR   |                              |  جورجيا الجنوبية وجزر ساندويتش الجنوبية
Q35086    |  NEWvalue  |  NAME_BN   |                              |  দক্ষিণ জর্জিয়া ও দক্ষিণ স্যন্ডউইচ দ্বীপপুঞ্জ
Q35086    |  NEWvalue  |  NAME_DE   |                              |  Südgeorgien und die Südlichen Sandwichinseln
Q35086    |  NEWvalue  |  NAME_EN   |                              |  South Georgia and the South Sandwich Islands
Q35086    |  NEWvalue  |  NAME_ES   |                              |  Islas Georgias del Sur y Sándwich del Sur
Q35086    |  NEWvalue  |  NAME_FR   |                              |  Géorgie du Sud-et-les Îles Sandwich du Sud
Q35086    |  NEWvalue  |  NAME_EL   |                              |  Νήσοι Νότια Γεωργία και Νότιες Σάντουιτς
Q35086    |  NEWvalue  |  NAME_HI   |                              |  दक्षिण जॉर्जिया एवं दक्षिण सैंडविच द्वीप समूह
Q35086    |  NEWvalue  |  NAME_HU   |                              |  Déli-Georgia és Déli-Sandwich-szigetek
Q35086    |  NEWvalue  |  NAME_ID   |                              |  Georgia Selatan dan Kepulauan Sandwich Selatan
Q35086    |  NEWvalue  |  NAME_IT   |                              |  Georgia del Sud e isole Sandwich meridionali
Q35086    |  NEWvalue  |  NAME_JA   |                              |  サウスジョージア・サウスサンドウィッチ諸島
Q35086    |  NEWvalue  |  NAME_KO   |                              |  사우스조지아 사우스샌드위치 제도
Q35086    |  NEWvalue  |  NAME_NL   |                              |  Zuid-Georgia en de Zuidelijke Sandwicheilanden
Q35086    |  NEWvalue  |  NAME_PL   |                              |  Georgia Południowa i Sandwich Południowy
Q35086    |  NEWvalue  |  NAME_PT   |                              |  Ilhas Geórgia do Sul e Sandwich do Sul
Q35086    |  NEWvalue  |  NAME_RU   |                              |  Южная Георгия и Южные Сандвичевы острова
Q35086    |  NEWvalue  |  NAME_SV   |                              |  Sydgeorgien och Sydsandwichöarna
Q35086    |  NEWvalue  |  NAME_TR   |                              |  Güney Georgia ve Güney Sandwich Adaları
Q35086    |  NEWvalue  |  NAME_VI   |                              |  Nam Georgia và Quần đảo Nam Sandwich
Q35086    |  NEWvalue  |  NAME_ZH   |                              |  南喬治亞島與南桑威奇群島
Q172216   |  NEWvalue  |  NAME_AR   |                              |  جزر بحر كورال
Q172216   |  NEWvalue  |  NAME_BN   |                              |  কোরাল সাগর দ্বীপপুঞ্জ
Q172216   |  NEWvalue  |  NAME_DE   |                              |  Korallenmeerinseln
Q172216   |  NEWvalue  |  NAME_EN   |                              |  Coral Sea Islands
Q172216   |  NEWvalue  |  NAME_ES   |                              |  Islas del Mar del Coral
Q172216   |  NEWvalue  |  NAME_FR   |                              |  Îles de la mer de Corail
Q172216   |  NEWvalue  |  NAME_EL   |                              |  Νησιά Θάλασσας των Κοραλίων
Q172216   |  NEWvalue  |  NAME_HI   |                              |  कोरल सागर द्वीप समूह
Q172216   |  NEWvalue  |  NAME_HU   |                              |  Korall-tengeri-szigetek
Q172216   |  NEWvalue  |  NAME_ID   |                              |  Kepulauan Laut Karang
Q172216   |  NEWvalue  |  NAME_IT   |                              |  Isole del Mar dei Coralli
Q172216   |  NEWvalue  |  NAME_JA   |                              |  コーラル・シー諸島
Q172216   |  NEWvalue  |  NAME_KO   |                              |  산호해 제도
Q172216   |  NEWvalue  |  NAME_NL   |                              |  Koraalzee-eilanden
Q172216   |  NEWvalue  |  NAME_PL   |                              |  Wyspy Morza Koralowego
Q172216   |  NEWvalue  |  NAME_PT   |                              |  Ilhas do Mar de Coral
Q172216   |  NEWvalue  |  NAME_RU   |                              |  Территория островов Кораллового моря
Q172216   |  NEWvalue  |  NAME_SV   |                              |  Korallhavöarna
Q172216   |  NEWvalue  |  NAME_TR   |                              |  Mercan Denizi Adaları
Q172216   |  NEWvalue  |  NAME_VI   |                              |  Quần đảo Biển San hô
Q172216   |  NEWvalue  |  NAME_ZH   |                              |  珊瑚海群岛
Q215664   |  NEWvalue  |  NAME_HU   |                              |  Spratly-szigetek
Q1257783  |  NEWvalue  |  NAME_AR   |                              |  ضفة باجو نيوفو
Q1257783  |  NEWvalue  |  NAME_BN   |                              |  বাজো নুয়েভো তীর
Q1257783  |  NEWvalue  |  NAME_DE   |                              |  Bajo-Nuevo-Bank
Q1257783  |  NEWvalue  |  NAME_EN   |                              |  Bajo Nuevo Bank
Q1257783  |  NEWvalue  |  NAME_ES   |                              |  Bajo Nuevo
Q1257783  |  NEWvalue  |  NAME_FR   |                              |  Banc de Bajo Nuevo
Q1257783  |  NEWvalue  |  NAME_EL   |                              |  Μπάτζο Νουέβο Μπανκ
Q1257783  |  NEWvalue  |  NAME_HI   |                              |  बाखो न्युएवो तट
Q1257783  |  NEWvalue  |  NAME_HU   |                              |  Petrel-szigetek
Q1257783  |  NEWvalue  |  NAME_ID   |                              |  Tepi Bajo Nuevo
Q1257783  |  NEWvalue  |  NAME_IT   |                              |  Bajo Nuevo Bank
Q1257783  |  NEWvalue  |  NAME_JA   |                              |  バホヌエボ
Q1257783  |  NEWvalue  |  NAME_KO   |                              |  바호 누에보 뱅크
Q1257783  |  NEWvalue  |  NAME_NL   |                              |  Bajo Nuevo
Q1257783  |  NEWvalue  |  NAME_PL   |                              |  Bajo Nuevo
Q1257783  |  NEWvalue  |  NAME_PT   |                              |  Ilha Baixo Novo
Q1257783  |  NEWvalue  |  NAME_RU   |                              |  Бахо-Нуэво
Q1257783  |  NEWvalue  |  NAME_SV   |                              |  Bajo Nuevo
Q1257783  |  NEWvalue  |  NAME_TR   |                              |  Bajo Nuevo Bank
Q1257783  |  NEWvalue  |  NAME_VI   |                              |  Bajo Nuevo Bank
Q1257783  |  NEWvalue  |  NAME_ZH   |                              |  巴霍努埃沃礁
Q628716   |  NEWvalue  |  NAME_HU   |                              |  Scarborough-zátony
Q628716   |  MODvalue  |  NAME_SV   |  Panatag                     |  Scarboroughrevet
